@@ -2,7 +2,6 @@ use std::collections::HashMap;
 use std::path::PathBuf;
 
 use regex::Regex;
-use structopt::clap;
 use syntect::highlighting::Style as SyntectStyle;
 use syntect::highlighting::Theme as SyntaxTheme;
 use syntect::parsing::SyntaxSet;
@@ -17,13 +16,18 @@ use crate::fatal;
 use crate::features::navigate;
 use crate::features::side_by_side::{self, ansifill, LeftRight};
 use crate::git_config::{GitConfig, GitConfigEntry};
+use crate::handlers;
+use crate::handlers::blame::parse_blame_line_numbers;
+use crate::handlers::blame::BlameLineNumbers;
 use crate::minusplus::MinusPlus;
 use crate::paint::BgFillMethod;
 use crate::parse_styles;
 use crate::style;
 use crate::style::Style;
 use crate::tests::TESTING;
+use crate::utils;
 use crate::utils::bat::output::PagingMode;
+use crate::utils::regex_replacement::RegexReplacement;
 use crate::utils::syntect::FromDeltaStyle;
 use crate::wrapping::WrapConfig;
 
@@ -56,15 +60,21 @@ fn adapt_wrap_max_lines_argument(arg: String) -> usize {
     }
 }
 
+#[cfg_attr(test, derive(Clone))]
 pub struct Config {
     pub available_terminal_width: usize,
     pub background_color_extends_to_terminal_width: bool,
+    pub blame_code_style: Option<Style>,
     pub blame_format: String,
+    pub blame_separator_format: BlameLineNumbers,
     pub blame_palette: Vec<String>,
+    pub blame_separator_style: Option<Style>,
     pub blame_timestamp_format: String,
     pub color_only: bool,
     pub commit_regex: Regex,
     pub commit_style: Style,
+    pub cwd_of_delta_process: Option<PathBuf>,
+    pub cwd_of_user_shell_process: Option<PathBuf>,
     pub cwd_relative_to_repo_root: Option<String>,
     pub decorations_width: cli::Width,
     pub default_language: Option<String>,
@@ -75,6 +85,7 @@ pub struct Config {
     pub file_modified_label: String,
     pub file_removed_label: String,
     pub file_renamed_label: String,
+    pub file_regex_replacement: Option<RegexReplacement>,
     pub right_arrow: String,
     pub file_style: Style,
     pub git_config_entries: HashMap<String, GitConfigEntry>,
@@ -151,6 +162,7 @@ impl Config {
     pub fn get_style(&self, state: &State) -> &Style {
         match state {
             State::HunkMinus(_, _) => &self.minus_style,
+            State::HunkZero(_, _) => &self.zero_style,
             State::HunkPlus(_, _) => &self.plus_style,
             State::CommitMeta => &self.commit_style,
             State::DiffHeader(_) => &self.file_style,
@@ -163,7 +175,7 @@ impl Config {
 
 impl From<cli::Opt> for Config {
     fn from(opt: cli::Opt) -> Self {
-        let styles = parse_styles::parse_styles(&opt);
+        let mut styles = parse_styles::parse_styles(&opt);
         let styles_map = parse_styles::parse_styles_map(&opt);
 
         let max_line_distance_for_naively_paired_lines =
@@ -233,18 +245,35 @@ impl From<cli::Opt> for Config {
 
         let wrap_max_lines_plus1 = adapt_wrap_max_lines_argument(opt.wrap_max_lines);
 
+        #[cfg(not(test))]
+        let cwd_of_delta_process = std::env::current_dir().ok();
+        #[cfg(test)]
+        let cwd_of_delta_process = Some(utils::path::fake_delta_cwd_for_tests());
+
+        let cwd_relative_to_repo_root = std::env::var("GIT_PREFIX").ok();
+
+        let cwd_of_user_shell_process = utils::path::cwd_of_user_shell_process(
+            cwd_of_delta_process.as_ref(),
+            cwd_relative_to_repo_root.as_deref(),
+        );
+
         Self {
             available_terminal_width: opt.computed.available_terminal_width,
             background_color_extends_to_terminal_width: opt
                 .computed
                 .background_color_extends_to_terminal_width,
             blame_format: opt.blame_format,
+            blame_code_style: styles.remove("blame-code-style"),
             blame_palette,
+            blame_separator_format: parse_blame_line_numbers(&opt.blame_separator_format),
+            blame_separator_style: styles.remove("blame-separator-style"),
             blame_timestamp_format: opt.blame_timestamp_format,
             commit_style: styles["commit-style"],
             color_only: opt.color_only,
             commit_regex,
-            cwd_relative_to_repo_root: std::env::var("GIT_PREFIX").ok(),
+            cwd_of_delta_process,
+            cwd_of_user_shell_process,
+            cwd_relative_to_repo_root,
             decorations_width: opt.computed.decorations_width,
             default_language: opt.default_language,
             diff_stat_align_width: opt.diff_stat_align_width,
@@ -254,6 +283,10 @@ impl From<cli::Opt> for Config {
             file_modified_label,
             file_removed_label,
             file_renamed_label,
+            file_regex_replacement: opt
+                .file_regex_replacement
+                .as_deref()
+                .and_then(RegexReplacement::from_sed_command),
             right_arrow,
             hunk_label,
             file_style: styles["file-style"],
@@ -291,7 +324,7 @@ impl From<cli::Opt> for Config {
             } else {
                 line_fill_method
             },
-            line_numbers: opt.line_numbers,
+            line_numbers: opt.line_numbers && !handlers::hunk::is_word_diff(),
             line_numbers_format: LeftRight::new(
                 opt.line_numbers_left_format,
                 opt.line_numbers_right_format,
@@ -306,7 +339,6 @@ impl From<cli::Opt> for Config {
             ),
             line_numbers_zero_style: styles["line-numbers-zero-style"],
             line_buffer_size: opt.line_buffer_size,
-            styles_map,
             max_line_distance: opt.max_line_distance,
             max_line_distance_for_naively_paired_lines,
             max_line_length: match (opt.side_by_side, wrap_max_lines_plus1) {
@@ -351,8 +383,9 @@ impl From<cli::Opt> for Config {
             git_plus_style: styles["git-plus-style"],
             relative_paths: opt.relative_paths,
             show_themes: opt.show_themes,
-            side_by_side: opt.side_by_side,
+            side_by_side: opt.side_by_side && !handlers::hunk::is_word_diff(),
             side_by_side_data,
+            styles_map,
             syntax_dummy_theme: SyntaxTheme::default(),
             syntax_set: opt.computed.syntax_set,
             syntax_theme: opt.computed.syntax_theme,
