@@ -12,6 +12,7 @@ use crate::features::OptionValueFunction;
 use crate::format::{self, Align, Placeholder};
 use crate::minusplus::*;
 use crate::style::Style;
+use crate::utils;
 
 pub fn make_feature() -> Vec<(String, OptionValueFunction)> {
     builtin_feature!([
@@ -261,10 +262,7 @@ fn format_and_paint_line_number_field<'a>(
             min_field_width
         };
 
-        let alignment_spec = placeholder
-            .alignment_spec
-            .as_ref()
-            .unwrap_or(&Align::Center);
+        let alignment_spec = placeholder.alignment_spec.unwrap_or(Align::Center);
         match placeholder.placeholder {
             Some(Placeholder::NumberMinus) => {
                 ansi_strings.push(styles[Minus].paint(format_line_number(
@@ -298,7 +296,7 @@ fn format_and_paint_line_number_field<'a>(
 /// Return line number formatted according to `alignment` and `width`.
 fn format_line_number(
     line_number: Option<usize>,
-    alignment: &Align,
+    alignment: Align,
     width: usize,
     precision: Option<usize>,
     plus_file: Option<&str>,
@@ -306,12 +304,15 @@ fn format_line_number(
 ) -> String {
     let pad = |n| format::pad(n, width, alignment, precision);
     match (line_number, config.hyperlinks, plus_file) {
-        (None, _, _) => pad(""),
-        (Some(n), true, Some(file)) => {
-            hyperlinks::format_osc8_file_hyperlink(file, line_number, &pad(&n.to_string()), config)
-                .to_string()
-        }
-        (Some(n), _, _) => pad(&n.to_string()),
+        (None, _, _) => " ".repeat(width),
+        (Some(n), true, Some(file)) => match utils::path::absolute_path(file, config) {
+            Some(absolute_path) => {
+                hyperlinks::format_osc8_file_hyperlink(absolute_path, line_number, &pad(n), config)
+                    .to_string()
+            }
+            None => file.to_owned(),
+        },
+        (Some(n), _, _) => pad(n),
     }
 }
 
@@ -339,12 +340,7 @@ pub mod tests {
             vec![format::FormatStringPlaceholderData {
                 prefix: "".into(),
                 placeholder: Some(Placeholder::NumberMinus),
-                alignment_spec: None,
-                width: None,
-                precision: None,
-                suffix: "".into(),
-                prefix_len: 0,
-                suffix_len: 0,
+                ..Default::default()
             }]
         )
     }
@@ -358,10 +354,7 @@ pub mod tests {
                 placeholder: Some(Placeholder::NumberPlus),
                 alignment_spec: None,
                 width: Some(4),
-                precision: None,
-                suffix: "".into(),
-                prefix_len: 0,
-                suffix_len: 0,
+                ..Default::default()
             }]
         )
     }
@@ -376,9 +369,7 @@ pub mod tests {
                 alignment_spec: Some(Align::Right),
                 width: Some(4),
                 precision: None,
-                suffix: "".into(),
-                prefix_len: 0,
-                suffix_len: 0,
+                ..Default::default()
             }]
         )
     }
@@ -392,10 +383,7 @@ pub mod tests {
                 placeholder: Some(Placeholder::NumberPlus),
                 alignment_spec: Some(Align::Right),
                 width: Some(4),
-                precision: None,
-                suffix: "".into(),
-                prefix_len: 0,
-                suffix_len: 0,
+                ..Default::default()
             }]
         )
     }
@@ -413,6 +401,7 @@ pub mod tests {
                 suffix: "@@".into(),
                 prefix_len: 2,
                 suffix_len: 2,
+                ..Default::default()
             }]
         )
     }
@@ -431,6 +420,7 @@ pub mod tests {
                     suffix: "@@---{np:_>4}**".into(),
                     prefix_len: 2,
                     suffix_len: 15,
+                    ..Default::default()
                 },
                 format::FormatStringPlaceholderData {
                     prefix: "@@---".into(),
@@ -441,6 +431,7 @@ pub mod tests {
                     suffix: "**".into(),
                     prefix_len: 5,
                     suffix_len: 2,
+                    ..Default::default()
                 }
             ]
         )
@@ -459,6 +450,7 @@ pub mod tests {
                 suffix: "__@@---**".into(),
                 prefix_len: 0,
                 suffix_len: 9,
+                ..Default::default()
             },]
         )
     }
@@ -476,6 +468,7 @@ pub mod tests {
                 suffix: "|".into(),
                 prefix_len: 2,
                 suffix_len: 1,
+                ..Default::default()
             }]
         );
     }
@@ -498,6 +491,7 @@ pub mod tests {
                     suffix: "+{np:<4}|".into(),
                     prefix_len: 2,
                     suffix_len: 9,
+                    ..Default::default()
                 },
                 format::FormatStringPlaceholderData {
                     prefix: "+".into(),
@@ -508,6 +502,7 @@ pub mod tests {
                     suffix: "|".into(),
                     prefix_len: 1,
                     suffix_len: 1,
+                    ..Default::default()
                 }
             ]
         );
@@ -525,6 +520,7 @@ pub mod tests {
                 suffix: "|++|".into(),
                 prefix_len: 1,
                 suffix_len: 4,
+                ..Default::default()
             }]
         );
     }
@@ -547,6 +543,7 @@ pub mod tests {
                 precision: None,
                 suffix: long.into(),
                 suffix_len: long.len(),
+                ..Default::default()
             },]
         )
     }
@@ -630,7 +627,7 @@ pub mod tests {
 
     #[test]
     fn test_two_minus_lines() {
-        DeltaTest::with(&[
+        DeltaTest::with_args(&[
             "--line-numbers",
             "--line-numbers-left-format",
             "{nm:^4}⋮",
@@ -646,17 +643,17 @@ pub mod tests {
             "0 4",
         ])
         .with_input(TWO_MINUS_LINES_DIFF)
-        .expect(
+        .expect_after_header(
             r#"
              #indent_mark
-              1  ⋮    │a = 1
-              2  ⋮    │b = 23456"#,
+               1 ⋮    │a = 1
+               2 ⋮    │b = 23456"#,
         );
     }
 
     #[test]
     fn test_two_plus_lines() {
-        DeltaTest::with(&[
+        DeltaTest::with_args(&[
             "--line-numbers",
             "--line-numbers-left-format",
             "{nm:^4}⋮",
@@ -672,11 +669,11 @@ pub mod tests {
             "0 4",
         ])
         .with_input(TWO_PLUS_LINES_DIFF)
-        .expect(
+        .expect_after_header(
             r#"
              #indent_mark
-                 ⋮ 1  │a = 1
-                 ⋮ 2  │b = 234567"#,
+                 ⋮  1 │a = 1
+                 ⋮  2 │b = 234567"#,
         );
     }
 
@@ -700,9 +697,9 @@ pub mod tests {
         let output = run_delta(ONE_MINUS_ONE_PLUS_LINE_DIFF, &config);
         let output = strip_ansi_codes(&output);
         let mut lines = output.lines().skip(crate::config::HEADER_LEN);
-        assert_eq!(lines.next().unwrap(), " 1  ⋮ 1  │a = 1");
-        assert_eq!(lines.next().unwrap(), " 2  ⋮    │b = 2");
-        assert_eq!(lines.next().unwrap(), "    ⋮ 2  │bb = 2");
+        assert_eq!(lines.next().unwrap(), "  1 ⋮  1 │a = 1");
+        assert_eq!(lines.next().unwrap(), "  2 ⋮    │b = 2");
+        assert_eq!(lines.next().unwrap(), "    ⋮  2 │bb = 2");
     }
 
     #[test]
@@ -725,9 +722,9 @@ pub mod tests {
         let output = run_delta(ONE_MINUS_ONE_PLUS_LINE_DIFF, &config);
         let output = strip_ansi_codes(&output);
         let mut lines = output.lines().skip(crate::config::HEADER_LEN);
-        assert_eq!(lines.next().unwrap(), " 1    1  ⋮ 1  │a = 1");
-        assert_eq!(lines.next().unwrap(), " 2    2  ⋮    │b = 2");
-        assert_eq!(lines.next().unwrap(), "         ⋮ 2  │bb = 2");
+        assert_eq!(lines.next().unwrap(), "  1    1 ⋮  1 │a = 1");
+        assert_eq!(lines.next().unwrap(), "  2    2 ⋮    │b = 2");
+        assert_eq!(lines.next().unwrap(), "         ⋮  2 │bb = 2");
     }
 
     #[test]
@@ -747,7 +744,7 @@ pub mod tests {
         let output = run_delta(UNEQUAL_DIGIT_DIFF, &config);
         let output = strip_ansi_codes(&output);
         let mut lines = output.lines().skip(crate::config::HEADER_LEN);
-        assert_eq!(lines.next().unwrap(), "10000⋮9999 │a = 1");
+        assert_eq!(lines.next().unwrap(), "10000⋮ 9999│a = 1");
         assert_eq!(lines.next().unwrap(), "10001⋮     │b = 2");
         assert_eq!(lines.next().unwrap(), "     ⋮10000│bb = 2");
     }
@@ -758,8 +755,8 @@ pub mod tests {
         let output = run_delta(TWO_MINUS_LINES_DIFF, &config);
         let mut lines = output.lines().skip(5);
         let (line_1, line_2) = (lines.next().unwrap(), lines.next().unwrap());
-        assert_eq!(strip_ansi_codes(line_1), " 1  ⋮    │-a = 1");
-        assert_eq!(strip_ansi_codes(line_2), " 2  ⋮    │-b = 23456");
+        assert_eq!(strip_ansi_codes(line_1), "  1 ⋮    │-a = 1");
+        assert_eq!(strip_ansi_codes(line_2), "  2 ⋮    │-b = 23456");
     }
 
     #[test]
@@ -768,30 +765,30 @@ pub mod tests {
         let output = run_delta(TWO_LINE_DIFFS, &config);
         let output = strip_ansi_codes(&output);
         let mut lines = output.lines().skip(4);
-        assert_eq!(lines.next().unwrap(), " 1  ⋮ 1  │a = 1");
-        assert_eq!(lines.next().unwrap(), " 2  ⋮    │b = 2");
-        assert_eq!(lines.next().unwrap(), "    ⋮ 2  │bb = 2");
+        assert_eq!(lines.next().unwrap(), "  1 ⋮  1 │a = 1");
+        assert_eq!(lines.next().unwrap(), "  2 ⋮    │b = 2");
+        assert_eq!(lines.next().unwrap(), "    ⋮  2 │bb = 2");
         assert_eq!(lines.next().unwrap(), "");
-        assert_eq!(lines.next().unwrap(), "499 ⋮499 │a = 3");
-        assert_eq!(lines.next().unwrap(), "500 ⋮    │b = 4");
-        assert_eq!(lines.next().unwrap(), "    ⋮500 │bb = 4");
+        assert_eq!(lines.next().unwrap(), " 499⋮ 499│a = 3");
+        assert_eq!(lines.next().unwrap(), " 500⋮    │b = 4");
+        assert_eq!(lines.next().unwrap(), "    ⋮ 500│bb = 4");
     }
 
     #[test]
     fn test_line_numbers_continue_correctly() {
-        DeltaTest::with(&["--side-by-side", "--width", "44", "--line-fill-method=ansi"])
+        DeltaTest::with_args(&["--side-by-side", "--width", "44", "--line-fill-method=ansi"])
             .with_input(DIFF_PLUS_MINUS_WITH_1_CONTEXT_DIFF)
-            .expect(
+            .expect_after_header(
                 r#"
-                │ 1  │abc             │ 1  │abc
-                │ 2  │a = left side   │ 2  │a = right side
-                │ 3  │xyz             │ 3  │xyz"#,
+                │  1 │abc             │  1 │abc
+                │  2 │a = left side   │  2 │a = right side
+                │  3 │xyz             │  3 │xyz"#,
             );
     }
 
     #[test]
     fn test_line_numbers_continue_correctly_after_wrapping() {
-        DeltaTest::with(&[
+        DeltaTest::with_args(&[
             "--side-by-side",
             "--width",
             "32",
@@ -802,12 +799,12 @@ pub mod tests {
             "@",
         ])
         .with_input(DIFF_PLUS_MINUS_WITH_1_CONTEXT_DIFF)
-        .expect(
+        .expect_after_header(
             r#"
-            │ 1  │abc       │ 1  │abc
-            │ 2  │a = left @│ 2  │a = right@
+            │  1 │abc       │  1 │abc
+            │  2 │a = left @│  2 │a = right@
             │    │side      │    │ side
-            │ 3  │xyz       │ 3  │xyz"#,
+            │  3 │xyz       │  3 │xyz"#,
         );
 
         let cfg = &[
@@ -821,47 +818,47 @@ pub mod tests {
             "@",
         ];
 
-        DeltaTest::with(cfg)
+        DeltaTest::with_args(cfg)
             .with_input(DIFF_WITH_LONGER_MINUS_1_CONTEXT)
-            .expect(
+            .expect_after_header(
                 r#"
-                │ 1  │abc            │ 1  │abc
-                │ 2  │a = one side   │ 2  │a = one longer@
+                │  1 │abc            │  1 │abc
+                │  2 │a = one side   │  2 │a = one longer@
                 │    │               │    │ side
-                │ 3  │xyz            │ 3  │xyz"#,
+                │  3 │xyz            │  3 │xyz"#,
             );
 
-        DeltaTest::with(cfg)
+        DeltaTest::with_args(cfg)
             .with_input(DIFF_WITH_LONGER_PLUS_1_CONTEXT)
-            .expect(
+            .expect_after_header(
                 r#"
-                │ 1  │abc            │ 1  │abc
-                │ 2  │a = one longer@│ 2  │a = one side
+                │  1 │abc            │  1 │abc
+                │  2 │a = one longer@│  2 │a = one side
                 │    │ side          │    │
-                │ 3  │xyz            │ 3  │xyz"#,
+                │  3 │xyz            │  3 │xyz"#,
             );
 
-        DeltaTest::with(cfg)
+        DeltaTest::with_args(cfg)
             .with_input(DIFF_MISMATCH_LONGER_MINUS_1_CONTEXT)
-            .expect(
+            .expect_after_header(
                 r#"
-                │ 1  │abc            │ 1  │abc
-                │ 2  │a = left side @│    │
+                │  1 │abc            │  1 │abc
+                │  2 │a = left side @│    │
                 │    │which is longer│    │
-                │    │               │ 2  │a = other one
-                │ 3  │xyz            │ 3  │xyz"#,
+                │    │               │  2 │a = other one
+                │  3 │xyz            │  3 │xyz"#,
             );
 
-        DeltaTest::with(cfg)
+        DeltaTest::with_args(cfg)
             .with_input(DIFF_MISMATCH_LONGER_PLUS_1_CONTEXT)
-            .expect(
+            .expect_after_header(
                 r#"
-                │ 1  │abc            │ 1  │abc
-                │ 2  │a = other one  │    │
-                │    │               │ 2  │a = right side@
+                │  1 │abc            │  1 │abc
+                │  2 │a = other one  │    │
+                │    │               │  2 │a = right side@
                 │    │               │    │ which is long@
                 │    │               │    │er
-                │ 3  │xyz            │ 3  │xyz"#,
+                │  3 │xyz            │  3 │xyz"#,
             );
     }
 
