@@ -79,18 +79,20 @@ pub trait GetOptionValue {
                 return Some(value);
             }
         }
-        for feature in opt.features.to_lowercase().split_whitespace().rev() {
-            match Self::get_provenanced_value_for_feature(
-                option_name,
-                &feature,
-                &builtin_features,
-                opt,
-                git_config,
-            ) {
-                Some(GitConfigValue(value)) | Some(DefaultValue(value)) => {
-                    return Some(value.into());
+        if let Some(features) = &opt.features {
+            for feature in features.split_whitespace().rev() {
+                match Self::get_provenanced_value_for_feature(
+                    option_name,
+                    feature,
+                    builtin_features,
+                    opt,
+                    git_config,
+                ) {
+                    Some(GitConfigValue(value)) | Some(DefaultValue(value)) => {
+                        return Some(value.into());
+                    }
+                    None => {}
                 }
-                None => {}
             }
         }
         None
@@ -120,7 +122,7 @@ pub trait GetOptionValue {
         }
         if let Some(builtin_feature) = builtin_features.get(feature) {
             if let Some(value_function) = builtin_feature.get(option_name) {
-                return Some(value_function(opt, &git_config));
+                return Some(value_function(opt, git_config));
             }
         }
         None
@@ -300,6 +302,44 @@ pub mod tests {
         remove_file(git_config_path).unwrap();
     }
 
+    #[test]
+    #[ignore] // FIXME
+    fn test_delta_features_env_var() {
+        let git_config_contents = b"
+[delta]
+    features = feature-from-gitconfig
+";
+        let git_config_path = "delta__test_delta_features_env_var.gitconfig";
+
+        let opt = integration_test_utils::make_options_from_args_and_git_config(
+            &[],
+            Some(git_config_contents),
+            Some(git_config_path),
+        );
+        assert_eq!(opt.features.unwrap(), "feature-from-gitconfig");
+        assert_eq!(opt.side_by_side, false);
+
+        env::set_var("DELTA_FEATURES", "side-by-side");
+        let opt = integration_test_utils::make_options_from_args_and_git_config(
+            &[],
+            Some(git_config_contents),
+            Some(git_config_path),
+        );
+        assert_eq!(opt.features.unwrap(), "side-by-side");
+        assert_eq!(opt.side_by_side, true);
+
+        env::set_var("DELTA_FEATURES", "+side-by-side");
+        let opt = integration_test_utils::make_options_from_args_and_git_config(
+            &[],
+            Some(git_config_contents),
+            Some(git_config_path),
+        );
+        assert_eq!(opt.features.unwrap(), "side-by-side feature-from-gitconfig");
+        assert_eq!(opt.side_by_side, true);
+
+        remove_file(git_config_path).unwrap();
+    }
+
     #[test]
     fn test_get_themes_from_config() {
         let git_config_contents = r#"
@@ -316,6 +356,9 @@ pub mod tests {
     light = true
     dark = true
 
+[delta "Uppercase-Theme"]
+    light = true
+
 [delta "not-a-theme"]
     max-line-distance = 0.6
 "#;
@@ -331,7 +374,12 @@ pub mod tests {
 
         assert_eq!(
             themes,
-            ["dark-theme", "light-and-dark-theme", "light-theme",]
+            [
+                "dark-theme",
+                "light-and-dark-theme",
+                "light-theme",
+                "Uppercase-Theme"
+            ]
         );
 
         remove_file(git_config_path).unwrap();
